@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/file7.6.tcl,v $
-# $Date: 1997/08/06 09:26:42 $
-# $Revision: 1.18.1.14 $
+# $Source: /home/nlfm/catless/Zircon/installer/RCS/file76.tcl,v $
+# $Date: 1998/09/07 12:01:48 $
+# $Revision: 1.18.1.15 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -20,3 +20,5 @@ proc filedelete {f} {file delete $f}
 proc copyfile {from to} {file copy -force $from $to}
 #
 proc mkReadable {file} { exec chmod a+r $file }
+#
+proc mkExecutable {file} { exec chmod a+rx $file }
