@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/install.tcl,v $
-# $Date: 1998/07/24 15:10:36 $
-# $Revision: 1.18.1.11 $
+# $Date: 1999/07/02 07:44:45 $
+# $Revision: 1.18.1.12 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -46,13 +46,6 @@ switch -glob [info tclversion] {
           release! Future versions of zircon will not support tcl7.*.} info 0 OK
 	update
     }
-8\.1 {
-	tk_dialog .err {Zircon Installer} {I see you are running \
-          tcl8.1. There is a bug in this version of tcl that crashes\
-	  this installer. Please install using tcl8.0p2} info 0 OK
-	update
-	exit 0
-    }
     default {}
 }
 #
