@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/windows.tcl,v $
-# $Date: 1998/04/14 12:22:07 $
-# $Revision: 1.18.1.16 $
+# $Source: /home/nlfm/Zircon/installer/RCS/windows.tcl,v $
+# $Date: 1998/09/07 12:01:54 $
+# $Revision: 1.18.1.17 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -25,7 +25,7 @@ proc install {argv} {
     }
 #
     set argv [doGlobals $argv]
-    set Lib [file join C: {Program Files} Zircon]
+    set Lib {C:\Program Files\Zircon}
     set Bin $Lib
     trace variable Lib w traceLib
     set Xtn .tcl
@@ -57,6 +57,8 @@ proc prog7 {args} { }
 proc sed {args} { }
 #
 proc whereLib {} { return {[pwd]} }
+#
+proc makeExecutable {file} { }
 
 
 
