@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Away.tcl,v $
-# $Date: 1998/05/22 12:53:07 $
-# $Revision: 1.18.1.21 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Away.tcl,v $
+# $Date: 1999/05/20 15:23:47 $
+# $Revision: 1.18.1.23 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -21,9 +21,9 @@ proc awayPanel {net} {
     checkbutton $w.bcst -text {Tell Channels} -variable ${net}(atchn) \
 	-command "asAction $net $w"
     checkbutton $w.call -text {Tell Callers} -variable ${net}(atcll)
-    grid $w.srv $w.bcst $w.call -sticky ew
-    grid x [checkbutton $w.auto -text {Auto Clear} \
-      -variable ${net}(autoclearaway) -state disabled] x -sticky ew
+    grid $w.srv $w.bcst $w.call -sticky w
+    grid configure [checkbutton $w.auto -text {Auto Clear} \
+      -variable ${net}(autoclearaway) -state disabled] -row 1 -column 1 -sticky w
     makeLB $w.aways -height 12 -width 40
     bind $w.aways.l <Button-1> "+ awayEnab $w"
     foreach act [$net aways] { $w.aways.l insert end $act }
