@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1999/07/07 12:13:06 $
-# $Revision: 1.18.1.188 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
+# $Date: 1999/08/16 13:44:40 $
+# $Revision: 1.18.1.189 $
 #
 #
 package provide zircon 1.18
@@ -1388,10 +1388,10 @@ proc channel_flag {this state} {
 	}
     }
     switch normal $state {
-	foreach w [$this splitusers] {
-	    catch {[$this ufrm].userBtn.$n conf -state disabled}
-	    if {[set x [indexHack $w.users.menu [$usr name] 3]] >=0} {
-		$w.users.menu entryconfigure $x -state disabled
+	foreach usr [$this splitusers] {
+	    catch {[set w [$this ufrm].userBtn.$usr] conf -state disabled}
+	    if {[set x [indexHack $win.users.menu [$usr name] 3]] >=0} {
+		$win.users.menu entryconfigure $x -state disabled
 	    }
 	}
     } default {
