@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Chat.tcl,v $
-# $Date: 1998/11/06 10:07:30 $
-# $Revision: 1.18.1.47 $
+# $Date: 1998/12/21 09:50:35 $
+# $Revision: 1.18.1.48 $
 #
 package provide zircon 1.18
 #
@@ -162,7 +162,7 @@ proc chat_save {this desc} { mncSave $desc $this defChat DChat }
 proc ChatServer {usr nk} {
     set net [$usr net]
     upvar #0 AChat$net AChat
-    foreach {AChat($usr) cinfo} [makeServer "acceptChat $usr"] break
+    foreach "AChat($usr) cinfo" [makeServer "acceptChat $usr"] break
     $usr ref
     $net CTCP DCC $nk "CHAT chat [ipPack [ipAddress]] [lindex $cinfo 2]"
 }
