@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Consts.tcl,v $
-# $Date: 1998/07/12 19:55:35 $
-# $Revision: 1.18.1.6 $
+# $Date: 1998/07/23 13:48:00 $
+# $Revision: 1.18.1.7 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -14,7 +14,7 @@ package provide zircon 1.18
 proc InitConsts {} {
     global cfgv zFileTypes mIRCCol vt100Colour inexp1 inexp2 cVars confData\
       znetList RCFV zircsrv Tabs ctcpCmds specialCmds ch29 zMorse underflags\
-      TypeCode rcSave rcOpt tls
+      TypeCode tls
     #
     array set tls {
 	coff	{Chat Offers}
@@ -24,24 +24,6 @@ proc InitConsts {} {
 	fGet	{Active File Gets}
     }
     #
-    array set rcSave {
-	all	{open jump quiet history buttons close closetime
-		 timestamp closeleave colour timeformat noshare scrollback}
-	Channel	{draw menu nocase join actionmode nocase nosort}
-	Message	{draw}
-	Notice	{}
-	Chat	{}
-    }
-    #
-    array set rcOpt {
-	all	{foreground background font geometry height width
-		  boldfont messages logfile icon}
-	Channel	{msg ops ban patterns topics key}
-	Message	{}
-	Notice	{}
-	Chat	{}
-    }
-    #
     array set TypeCode {
 	Channel	text
 	Message	msg
