@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
-# $Date: 1998/10/13 10:59:21 $
-# $Revision: 1.18.1.103 $
+# $Date: 1999/07/01 08:33:08 $
+# $Revision: 1.18.1.105 $
 #
 #
 package provide zircon 1.18
@@ -420,7 +420,7 @@ proc control_undernet {this flag} {
     } {
 	if {$six >= 0} {
 	    $smn delete $six
-	    $smn delete [$umn index [trans flags]]
+	    $smn delete [$smn index [trans map]]
 	    $umn delete [$umn index [trans silence]]
 	}
     }
