@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Friend.tcl,v $
-# $Date: 1998/06/22 15:04:40 $
-# $Revision: 1.18.1.10 $
+# $Date: 1998/07/14 09:32:17 $
+# $Revision: 1.18.1.12 $
 #
 package provide zircon 1.18
 #
@@ -12,6 +12,7 @@ proc Friend_save {desc net} {
     upvar #0 Configure.Friend defval
     set cm 1
     foreach x [$net friends] {
+        if {![$x keep]} continue
 	set ln "Friend [list [$x nick]]"
 	foreach y [array names defval] {
 	    switch -- [$x $y] $defval($y) continue
@@ -193,4 +194,16 @@ proc friend_appear {this uh} {
 	}
     }
 }
+#
+proc GlobFriend {pattern} {
+    global currentNet
+    $currentNet configure +globfriend $pattern
+}
+#
+proc globfon {net pargs args} {
+    switch nil [Friend :: find [set nk [lindex $pargs 5]] $net] {
+	$net eval "Friend [list $nk] -keep 0"
+    }
+}
+
 
