@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/IRC.tcl,v $
-# $Date: 1998/09/02 12:02:34 $
-# $Revision: 1.18.1.59 $
+# $Date: 1999/01/29 10:45:28 $
+# $Revision: 1.18.1.60 $
 #
 package provide zircon 1.18
 #
@@ -248,7 +248,7 @@ proc notAnon {c p} {
 }
 #
 proc ircPART {net prefix param pargs} {
-    set chan [Channel :: find [set chn [lindex $pargs 0]] $net]
+    switch nil [set chan [Channel :: find [set chn [lindex $pargs 0]] $net]] return
     if {[notAnon $chn $prefix]} {
 	set nkinfo [mungPrefix $net $prefix]
 	if {[lindex $nkinfo 1]} {$chan delete} {
