@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/List.tcl,v $
-# $Date: 1998/11/13 12:21:42 $
-# $Revision: 1.18.1.13 $
+# $Date: 1999/01/11 13:14:49 $
+# $Revision: 1.18.1.14 $
 #
 package provide zircon 1.18
 #
@@ -41,6 +41,23 @@ proc list_unshow {this} {
     set ldata(wid) {}
 }
 #
+proc list_save {this} {
+    if {[catch {tk_getSaveFile -defaultextension .txt} sfl]} {
+        $net errmsg "File error: $sfl"
+	return
+    }
+    switch $sfl {} return
+    if {[catch {open $sfl w} fd]} {
+        $net errmsg "Cannot open file \"$sfl\": $fd"
+	return
+    }
+    foreach x [[[$this wid] name].chn.l get 0 end] { puts $fd $x }
+    if {[catch {close $fd} msg]} {
+        $net errmsg "Close error for \"$sfl\": $msg"
+	return
+    }
+}
+#
 proc list_configure {this args} { confObj $this $args }
 #
 proc list_show {this} {
@@ -101,9 +118,14 @@ proc list_show {this} {
 	  -command "$this unshow"
 	button $w.btn.clear -text [trans clear] -relief raised \
 	  -command "$this clear"
+	button $w.btn.save -text [trans save] -relief raised \
+	  -command "$this save"
+	switch -glob -- [info tclversion] 7.* {
+	    $w.btn.save configure -state disabled
+	}
 	button $w.btn.list -text [trans list] -relief raised \
 	  -command "$this doit"
-	grid $w.btn.list $w.btn.clear $w.btn.ok -sticky ew
+	grid $w.btn.list $w.btn.clear $w.btn.save $w.btn.ok -sticky ew
 	grid columnconfigure $w 0 -weight 1
 	grid rowconfigure $w 3 -weight 1
 	grid $w.filter -sticky ew
