@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Look.tcl,v $
-# $Date: 1998/07/14 15:42:25 $
-# $Revision: 1.18.1.21 $
+# $Date: 1998/07/16 15:22:29 $
+# $Revision: 1.18.1.23 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -48,7 +48,12 @@ proc getNet {ptn} {
 	    global currentNet
 	    regsub -all {[][+*\^$()|?]} [$currentNet name] {\\&} nn
 	    set ptn "^$nn\$"
-	} {
+	}  {
+	    set ptn .+
+	}
+    } default {
+	if {![checkRE $ptn]} {
+	    tellError {} Error "Bad net regular expression for share or merge - \"$nn\""
 	    set ptn .+
 	}
     }
@@ -64,14 +69,22 @@ proc look {args} {
     3 { set net [getNet [lindex $args 1]] ; set desc [lindex $args 2] }
     default { error "Invalid look statement" }
     }
-    set Look([newName Look]) [list $currentNet $type $cptn $net $desc]
+    if {[checkRE $cptn]} {
+ 	set Look([newName Look]) [list $currentNet $type $cptn $net $desc]
+    } {
+	tellError {} Error "Bad look regular expression \"$cptn\""
+    }
 }
 #
 proc merge {args} {
     global Share currentNet
     set args [getType $args t]
-    set Share([newName Share]) \
-      [list $currentNet $t [string tolower [lindex $args 0]] [getNet [lindex $args 1]] 1 1]
+    if {![checkRE [set cptn [string tolower [lindex $args 0]]]]} {
+        tellError {} Error "Bad pattern for merge command - \"$cptn\""
+    } {
+	set Share([newName Share]) \
+	  [list $currentNet $t $cptn [getNet [lindex $args 1]] 1 1]
+    }
 }
 #
 proc share {args} {
@@ -81,25 +94,29 @@ proc share {args} {
     if {[regexp {^\*([0-9]+)$} [lindex $args 0] m cols]} {
         set args [lrange $args 1 end]
     }
-    set Share([newName Share]) \
-      [list $currentNet $t [string tolower [lindex $args 0]] [getNet [lindex $args 1]] 0 $cols]
+    if {![checkRE [set cptn [string tolower [lindex $args 0]]]]} {
+        tellError {} Error "Bad pattern for share command - \"$cptn\""
+    } {
+	set Share([newName Share]) \
+	  [list $currentNet $t $cptn [getNet [lindex $args 1]] 0 $cols]
+    }
 }
 #
 proc InitLook {} {
     dispAd {Initialising look...}
     global Look DLook
-    look -channel {^\\+.*$} {.*} {
-	        {Popper {Info {limit create url topic}} {Flags {key mod log}}}
-	        {Popper {Control {Mode Info Action Users Quit Clear}}}
-	        {Text Users}
-	        {{Entry scroll}}
-	    }
-    look -channel {^\\&.*$} {.*} {
-	        {Popper {Info {limit create url topic}} {Flags {key mod log}}}
-	        {Popper {Control {Mode Info Action Users Quit Clear}}}
-	        {Text {Users off}}
-	        {{Entry scroll}}
-	    }
+    look -channel {^\\+.*$} {.*} [list \
+	        [list [list Popper] [list Info [list limit create url topic]] [list Flags [list key mod log]]] \
+	        [list [list Popper] [list Control [list Mode Info Action Users Quit Clear]]] \
+	        [list [list Text] [list Users]] \
+	        [list [list Entry scroll]] \
+	    ]
+    look -channel {^\\&.*$} {.*} [list \
+	        [list [list Popper] [list Info [list limit create url topic]] [list Flags [list key mod log]]] \
+	        [list [list Popper] [list Control [list Mode Info Action Users Quit Clear]]]\
+	        [list [list Text] [list Users off]]\
+	        [list [list Entry scroll]]\
+	    ]
     look -channel {.*} {.*} [list \
 		[list [list Popper] [list Topic]] \
 	        [list [list Popper] [list Info [list limit create url topic]] [list Flags [list key mod log]]] \
