@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Monitor.tcl,v $
-# $Date: 1998/11/13 12:21:43 $
-# $Revision: 1.18.1.19 $
+# $Date: 1998/11/16 14:10:55 $
+# $Revision: 1.18.1.20 $
 #
 package provide zircon 1.18
 #
@@ -19,6 +19,68 @@ proc monitor_remove {this usr} {
     if {![catch {destroy [$this window].usr.$usr}]} { $usr deref }
 }
 #
+proc msortIns {win un usr tg} {
+    set wnk $win.$usr
+    set fn name
+    set fn1 nop
+    set op 0
+    set spk 0
+    switch -- $tg {
+      @ { set op 1 }
+      + { set spk 1 }
+    }
+    if {[[$usr net] ircIIops]} {
+	set txt $tg$un
+    } {
+	set txt $un
+    }
+    set srt 1
+    set top text
+    set wd [$win cget -width]
+    switch nil [set fr [$usr fobj]] {} default {
+	switch {} [set fg [$fr images]] {} default {
+	   set top image
+	   set img [lindex $fg 0]
+	   set wd {}
+	   switch -glob -- $txt {
+	   @* {
+		    switch {} [set oi [lindex $fg 1]] {} default {set img $oi}
+	       }
+	   +* {
+		    switch {} [set oi [lindex $fg 2]] {} default {set img $oi}
+	       }
+	   }
+	   set txt $img
+	}
+    }
+    menubutton $wnk -$top $txt -highlightthickness 0 -borderwidth 2 -pady 1 -padx 2
+    switch {} $wd {} default { $wnk configure -width $wd }
+    $wnk configure -menu [makeUserMenu nil $wnk.menu $usr]
+    if {$srt} {
+	set y 1
+	while {![catch {set x [$win window cget 1.$y -window]}]} {
+	    switch {} $x {} default {
+	    	set u2 [winfo name $x]
+		switch [$fn1 $op $spk $u2] {
+		0 { }
+		1 {
+		    if {[string compare $un [$u2 $fn]] < 0} {
+		        $win window create [$win index $x] -window $wnk -padx 0
+		        return
+		    }
+		  }
+		2 {
+		    $win window create [$win index $x] -window $wnk -padx 0
+		    return
+		   }
+		}
+	    }
+	    incr y
+	}
+    }
+    $win window create end -window $wnk -padx 0
+}
+#
 proc monitor_update {this names} {
     if {![winfo exists [set w [$this window]]]} return
     set xist {}
@@ -29,7 +91,7 @@ proc monitor_update {this names} {
 	regexp {^([@+]?)(.*)} $n m mrk n
 	set usr [User :: make $net $n]
 	if {![winfo exists [set winu $w.usr.$usr]]} {
-	    wsortIns nil $w.usr $n $usr $mrk
+	    msortIns $w.usr $n $usr $mrk
 	    $usr ref
 	} {
 	    if {![normal $winu]} {
