@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Netspace.tcl,v $
-# $Date: 1998/12/03 17:06:59 $
-# $Revision: 1.18.1.23 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Netspace.tcl,v $
+# $Date: 1998/12/21 09:50:42 $
+# $Revision: 1.18.1.24 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -119,7 +119,6 @@ proc nsUnload {name} {
 		setUnload $name disabled
 	    }
 	    delFromConf $name
-zshow "call $x delete"
 	    $x delete
 	    break
 	}
