@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Notrace.tcl,v $
-# $Date: 1998/11/06 10:07:36 $
-# $Revision: 1.18.1.31 $
+# $Date: 1999/02/23 13:22:48 $
+# $Revision: 1.18.1.32 $
 #
 #
 package provide Notrace 1.18
@@ -221,7 +221,7 @@ proc acceptChat {usr newc hst args} {
     set chdata(who) $usr
     $usr ref
     set chdata(obj) $cht
-    fconfigure $newc -buffering none -blocking 0 -translation {auto lf}
+    fconfigure $newc -buffering none -blocking 0 -translation auto
     fileevent $newc readable "dccChat r $newc"
     catch {close $AChat($usr)}
     catch {unset AChat($usr)}
