@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Tags.tcl,v $
-# $Date: 1998/10/28 17:27:08 $
-# $Revision: 1.18.1.5 $
+# $Source: /catless/catless/nlfm/Working/Zircon/Released/lib/RCS/Tags.tcl,v $
+# $Date: 1999/05/14 10:53:50 $
+# $Revision: 1.18.1.8 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -13,6 +13,21 @@
 #
 package provide zircon 1.18
 #
+proc URLOpen {chid win x y} {
+    foreach {line ch} [split [$win index @$x,$y] .] break
+    foreach {l r} [$win tag ranges @url@] {
+       foreach {ll cl} [split $l .] break
+       if {$ll != $line} continue
+       if {$cl <= $ch} {
+           foreach {lr cr} [split $r .] break
+	   if {$ch <= $cr} {
+	       handleURL [$chid net] [$win get $l $r]
+	       break
+	   }
+       }
+    }
+}
+#
 proc setProps {chan args} {
     foreach win $args {
 	foreach x {font background foreground} {
@@ -20,6 +35,8 @@ proc setProps {chan args} {
 	    $win configure -$x $v
 	}
         switch {} [$chan colour] {} default { makeColourTags $win }
+	$win tag configure @url@ -foreground [[$chan net] urlcolour]
+	$win tag bind @url@ <Double-1> "URLOpen $chan %W %x %y"
     }
 }
 #
@@ -161,7 +178,7 @@ proc insertText {this name text tag} {
 	while {[regexp \
 	  "^(\[^\002\003\007\017\026\033\037\]*)(\[\002\003\007\017\026\033\037\])(.*)$" \
 	  $text match m1 ch text]} {
-	    $name insert end $m1 $taglist
+	    URLInsert $name $m1 $taglist
 	    switch -- $ch {
 	    \002 { set spc @b@ }
 	    \007 {
@@ -238,5 +255,20 @@ proc insertText {this name text tag} {
 	    } {	set taglist [lreplace $taglist $x $x] }
 	}
     }
-    $name insert end $text $taglist
+    URLInsert $name $text $taglist
+}
+#
+proc URLInsert {win text taglist} {
+    switch {} $text return
+    while {[regexp -indices \
+      "(http|https|ftp|news|telnet|file)(:/+\[^ \n\t\"\>]+\[^ \n\t,\.\)>\'\"\])" \
+      $text match]} {
+        foreach {lft rgt} $match break
+        if {$lft > 0} {
+            $win insert end [string range $text 0 [expr {$lft - 1}]] $taglist
+	}
+	$win insert end [string range $text $lft $rgt] [join [list @url@] $taglist]
+        set text [string range $text [expr {$rgt + 1}] end]
+    }
+    $win insert end $text $taglist
 }
