@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Undernet.tcl,v $
-# $Date: 1998/07/10 13:33:53 $
-# $Revision: 1.18.1.14 $
+# $Source: /home/nlfm/Working/Zircon/lib/RCS/Undernet.tcl,v $
+# $Date: 1999/07/23 09:17:37 $
+# $Revision: 1.18.1.15 $
 #
 package provide zircon 1.18
 #
@@ -51,7 +51,7 @@ proc underList {net chan} {
     set par {}
     if {$max > 0} { set par <[incr max],}
     switch {} $chan {
-	$net q1Send "LIST :$par>[incr min]"
+	$net q1Send "LIST :$par>[incr min -1]"
     } default {
 	$net q1Send "LIST $par>[incr min] :$chan"
     }
