@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/catless/Zircon/lib/RCS/Unix.tcl,v $
-# $Date: 1998/02/09 16:56:55 $
-# $Revision: 1.18.1.5 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Unix.tcl,v $
+# $Date: 1998/11/03 09:40:31 $
+# $Revision: 1.18.1.6 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -18,7 +18,7 @@ proc tmpdir {} {
     return /tmp
 }
 #
-proc prefdir {} { return [file join [glob ~] .zircon] }
+proc prefdir {} { return [file join [lindex [glob ~] 0] .zircon] }
 #
 proc username {} {
     global env
