@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Util.tcl,v $
-# $Date: 1998/12/03 17:07:01 $
-# $Revision: 1.18.1.81 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
+# $Date: 1999/06/16 11:36:23 $
+# $Revision: 1.18.1.83 $
 #
 package provide zircon 1.18
 #
@@ -130,6 +130,66 @@ proc addDCCMenu {name usr} {
       -command "doDCC [$usr net] [string toupper $cmd] \[$usr name\]" }
 }
 #
+proc newNickAction {net win usr chid} {
+    mkEntryBox .@${usr}action [trans action] "Enter your action for [$usr name]:" \
+      [list [list action {} {} palette]] \
+      [list send "NickAction 1 0 $net $win $usr $chid"] [list {send & keep} "NickAction 1 1 $net $win $usr $chid"] \
+      [list keep "NickAction 0 1 $net $win $usr $chid"] [list cancel {}]
+}
+#
+proc NickAction {send keep net win usr chid action} {
+    if {$send} { $chid doNickAction $usr $action }
+    if {$keep} {
+        $chid configure +nickactions [list [$usr name] $action]
+	$win.action add command -label [prune $action 15] \
+	  -command "$chid doNickAction $usr [list $action]"
+    }
+}
+#
+proc addActionMenu {net win usr chid} {
+    if {![$chid isa Channel]} return
+    $win add cascade -label [trans action] -menu $win.action
+    menu $win.action -tearoff 0
+    $win.action add command -label [trans New] \
+      -command "newNickAction $net $win $usr $chid"
+    $win.action add separator
+    foreach x [$net nickactions] {
+        foreach {chan nick label action} $x break
+	switch {} $action {
+	    set action $label
+	    set label [prune $action 12]
+	}
+	if {[regexp $chan [$chid name]] && [regexp $nick [$usr name]]} {
+	    $win.action add command -label $label \
+	      -command "$chid doNickAction $usr [list $action]"
+	}
+    }
+    foreach x [$chid nickactions] {
+        foreach {nick label action} $x break
+	switch {} $action {
+	    set action $label
+	    set label [prune $action 12]
+	}
+	if {[regexp $nick [$usr name]]} {
+	    $win.action add command -label $label \
+	      -command "$chid doNickAction $usr [list $action]"
+	}
+    }
+    switch nil [set frd [$usr fobj]] {} default {
+        foreach x [$frd actions] {
+            foreach {chan label action} $x break
+	    switch {} $action {
+	        set action $label
+	        set label [prune $action 12]
+	    }
+	    if {[regexp $chan [$chid name]]} {
+	        $win.action add command -label $label \
+	          -command "$chid doNickAction $usr [list $action]"
+	    }
+	}
+    }
+}
+#
 proc makeUserMenu {chid win usr} {
     if {[winfo exists $win]} { return $win }
     return [menu $win -postcommand "postUM $chid $win $usr"]
@@ -145,6 +205,7 @@ proc postUM {chid win usr} {
 	Whois	{$net WHOIS \[$usr lname\]}
 	Message	{Message :: make $net \[$usr name\]}
 	Notice	{channelNotice $net \[$usr lname\]}
+	Action	{}
 	Time	{$net TIME \[$usr name\]}
 	CTCP	{}
 	DCC	{}
@@ -160,6 +221,7 @@ proc postUM {chid win usr} {
     "
     foreach cmd $Ops(userMenu) {
 	switch $cmd {
+	Action { addActionMenu $net $win $usr $chid}
 	CTCP { addCTCPMenu $net $win $usr }
 	DCC { addDCCMenu $win $usr }
 	Notify {
@@ -324,16 +386,6 @@ proc ipAddress {} {
     return $hostIPaddress
 }
 #
-#proc acceptCon {cmd p1 p2} { fileevent $p1 readable $cmd }
-#
-#proc server {cmd} {
-#    set fd [socket -server "acceptCon {$cmd}" 0]
-#    if {[catch {fconfigure $fd -sockname} xx]} {
-#	error "Cannot get port for server - $xx"
-#   }
-#    return [list $fd [lindex $xx 2]]
-#}
-#
 proc makeServer {cmd} {
     if {[catch {socket -server $cmd 0} sock]} { error $sock }
     if {[catch {fconfigure $sock -sockname} xx]} {
