@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/confChan.tcl,v $
-# $Date: 1998/11/16 14:11:02 $
-# $Revision: 1.18.1.33 $
+# $Date: 1998/11/23 10:32:26 $
+# $Revision: 1.18.1.34 $
 #
 package provide zircon 1.18
 #
@@ -16,10 +16,11 @@ proc editChan {net pos win chan} {
     set news(lname) $lchan
 }
 #
-proc selectDefault {net} {
-    global defChan selID
-    set selID($net) $defChan($net)
-    setCCB $net $defChan($net)
+proc selectDefault {net var} {
+    global selID
+    upvar #0 $var deflt
+    set selID($net) $deflt($net)
+    setCCB $net $deflt($net)
 }
 #
 proc selChan {net win y} {
@@ -88,7 +89,7 @@ proc setCCB {net chan args} {
 }
 #
 proc CancelCAC {net win posn args} {
-    selectDefault $net
+    selectDefault $net defChan
     confSelClear $win [expr [$win size] - 2]
 }
 #
@@ -327,9 +328,6 @@ proc copybackChan {net} {
     confDirty $net
 }
 #
-proc confMessages {net win} {
-}
-#
 proc confNotices {net win} {
 }
 #
