@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/confTab.tcl,v $
-# $Date: 1998/12/07 13:14:47 $
-# $Revision: 1.18.1.20 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confTab.tcl,v $
+# $Date: 1999/08/18 10:42:01 $
+# $Revision: 1.18.1.21 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -178,6 +178,7 @@ proc confCleaner {net} {
     $net configure -confChange [listremove [$net confChange] $lastConf($net)]
     set win .@conf$net
     foreach bt {apply} { $win.btn.$bt configure -state disabled }
+    $win.btn.dismiss configure -state normal
     catch {unset tablock($net)}
 }
 #
@@ -186,6 +187,7 @@ proc confClean {net} {
     $net configure -confChange [listremove [$net confChange] $lastConf($net)]
     set win .@conf$net
     foreach bt {revert apply save} { $win.btn.$bt configure -state disabled }
+    $win.btn.dismiss configure -state normal
     catch {unset tablock($net)}
 }
 #
