@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/config.tcl,v $
-# $Date: 1998/11/16 14:11:05 $
-# $Revision: 1.18.1.35 $
+# $Date: 1998/11/23 10:32:37 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -24,6 +24,12 @@ proc confInit {net which} {
 	    set delChn($net) {}
 	    Channel :: pack $net
 	}
+    Messages {
+	    global newMsg delMsg
+	    set newMsg($net) {}
+	    set delMsg($net) {}
+	    Message :: pack $net
+	}
     Servers {
 	    global newSv delSv
 	    set newSv($net) {}
@@ -48,6 +54,17 @@ proc confCopyBack {net which} {
 	    }
 	    copybackChan $net
 	}
+    Messages {
+	    global delMsg
+	    foreach v $delMsg($net) {
+		if {[$v active]} {
+		} {
+		    $v delete
+		    uplevel #0 unset new$v
+		}
+	    }
+	    copybackMsg $net
+	}
     Servers {
 	    global newSv delSv svd$net
 	    confDirty $net
