@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
-# $Date: 1998/11/13 12:21:51 $
-# $Revision: 1.18.1.178 $
+# $Date: 1999/01/29 10:45:36 $
+# $Revision: 1.18.1.179 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -61,9 +61,17 @@ proc net {var val} {
 #
 proc away {args} { global currentNet ; $currentNet configure +aways [join $args] }
 #
-proc nick {args} { global currentNet ; $currentNet configure +nicks [join $args] }
+proc nick {args} {
+    global currentNet
+    switch {} [set foo [join $args]] return
+    $currentNet configure +nicks $foo
+}
 #
-proc ircname {args} { global currentNet ; $currentNet configure +ircnames [join $args] }
+proc ircname {args} {
+   global currentNet
+   switch {} [set foo [join $args]] return
+   $currentNet configure +ircnames $foo
+}
 #
 proc action {args} { global currentNet ; $currentNet configure +actions [join $args] }
 #
