@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/main.tcl,v $
-# $Date: 1998/11/23 10:32:40 $
-# $Revision: 1.18.1.89 $
+# $Date: 1999/05/17 09:34:56 $
+# $Revision: 1.18.1.92 $
 #
 package provide zircon 1.18
 #
@@ -133,7 +133,7 @@ proc irc001 {net prefix param pargs} {
     }
     $net inform $param
     $net setupTests
-    if {![$net noRefresh]} { $this channelList { } }
+    if {![$net noRefresh]} { $net channelList { } }
     handleOn $net STARTUP [list [$srv host] [$srv port]]
 }
 #
@@ -253,7 +253,20 @@ proc irc303 {net prefix param pargs} {
 	eval $cmd
     }
     foreach x $signInfo($net) {$net sysQ "USERHOST :[$x name]"}
-    foreach x $signons { handleOn $net ISON $x }
+    doSignons $net $signons
+}
+#
+proc doSignons {net signons} {
+    set mems [$net memos]
+    foreach x $signons {
+        handleOn $net ISON $x
+	if {[ set ix [lsearch $mems "$x *"]] >= 0} {
+	    set mm [lindex $mems $ix]
+	    $net PRIVMSG $x [lindex $mm 1]
+	    set mems [lreplace $mems $ix $ix]
+	}
+    }
+    $net configure -memos $mems
 }
 #
 proc who303 {net args} { foreach x $args { $net q1Send "WHOIS [colonLast $x]" } }
