@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/misc.tcl,v $
-# $Date: 1998/11/06 10:07:44 $
-# $Revision: 1.18.1.49 $
+# $Date: 1999/05/17 09:34:58 $
+# $Revision: 1.18.1.53 $
 #
 package provide zircon 1.18
 #
@@ -195,9 +195,9 @@ proc irc302 {net prefix param pargs} {
 		  "[getDate] :\nSignon by $signOns($net)" [list dismiss {}] \
 		  [list whois "who303 $net [list $signNOns($net)]"] \
 		  [list message "Message :: make $net [$usr name]"]
-		foreach x $signNOns($net) { handleOn $net ISON [list $x] }
+		doSignons $net $signNOns($net)
 	    }
-	    safeUnset signInfo($net) signOns($net) signNOns($net)
+	    safeUnset signInfo($net) signNOns($net) signOns($net)
 	}
     } \
     elseif {[info exists fingerInfo($net)]} {
@@ -433,20 +433,14 @@ proc handleURL {net url} {
     global zircon
     if {[info exists zircon(cciport)]} {
 	if {![string compare $zircon(cciport) netscape]} {
-	    if {[catch {exec netscape -remote openurl($url,newwindow)}]} {
+            regsub -all % $url %% url1
+            regsub -all , $url1 %2c url1
+	    if {[catch {exec netscape -remote openurl($url1,newwindow)}]} {
 		exec netscape $url &
 	    }
 	} \
-	elseif {[catch {$net connect localhost $zircon(cciport)} ccisock]} {
-	    $net errmsg "Cannot connect to WWW viewer ($val)"
-	} {
-	    set url [string trim $url]
-	    gets $ccisock res
-	    puts $ccisock "GET URL <$url> OUTPUT NEW\r"
-	    gets $ccisock res
-	    puts $ccisock "DISCONNECT\r"
-	    close $ccisock
-	    return
+	else {
+	    $net errmsg "CCI comms no longer supported. Sorry."
 	}
     }
     if {[info exists zircon(wwwclient)]} { exec $zircon(wwwclient) $url & }
@@ -489,7 +483,7 @@ proc findURL {win x y net} {
     set ls [$win index "@$x,$y linestart"]
     set txt [$win get $ls "@$x,$y lineend"]
     if {[regexp -nocase -indices \
-      "((http|gopher|ftp|wais|telnet)://\[^ \t\)>\",;&\]+)" \
+      "((http|gopher|ftp|wais|telnet|file)://\[^ \t\)>\",;&\]+)" \
       $txt url mt]} {
 	$win tag remove sel 0.0 end
 	set se [expr [lindex $mt 1] + 1]
@@ -512,3 +506,8 @@ proc getHelp {net} {
     mkEntryBox .@help$net [trans help] {Enter topic on which you need help:} \
       $ents [list ok "doHelp $net"] [list cancel {}]
 }
+#
+proc net_addMemo {net nk msg} {
+    upvar #0 $net ndata
+    lappend ndata(memos) [list $nk $msg]
+}
