@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1999/01/29 13:08:55 $
-# $Revision: 1.18.1.42 $
+# $Date: 1999/09/14 09:08:36 $
+# $Revision: 1.18.1.43 $
 #
 #
 package provide zircon 1.18
@@ -53,7 +53,11 @@ proc ircII_/ASSIGN {net chid arg} {
 #
 proc ircII_/AWAY {net chid arg} { $net AWAY $arg }
 #
-proc ircII_/BEEP {args} { bell }
+proc ircII_/BEEP {net chid arg} {
+    foreach nk $arg {
+	$net q1Send "PRIVMSG $nk :\a"
+    }
+}
 #
 proc ircII_/BIND {net chid arg} { sillyPerson $net }
 #
