@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/servers.tcl,v $
-# $Date: 1998/05/22 12:53:24 $
-# $Revision: 1.18.1.20 $
+# $Source: /home/nlfm/Zircon/lib/RCS/servers.tcl,v $
+# $Date: 1998/07/10 13:34:05 $
+# $Revision: 1.18.1.21 $
 #
 package provide zircon 1.18
 #
@@ -169,10 +169,8 @@ proc tracewin {op net prefix param pargs args} {
     }
     upvar #0 $var wstat
     if {![info exists wstat($net)]} {
-	set w [toplevel .@[newName trace] -class Zircon]
-	wm resizable $w 1 1
-	wm protocol $w WM_DELETE_WINDOW "destroy $w ; catch {unset ${var}($net)}"
-	wm title $w "$type for $tsite"
+	makeToplevel [set w .@[newName trace]] "$type for $tsite" \
+	  "destroy $w ; catch {unset ${var}($net)}" {}
 	grid columnconfigure $w 0 -weight 1
 	grid rowconfigure $w 0 -weight 1
 	scrollbar $w.vs -command "$w.txt yview"
