@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/userCmds.tcl,v $
-# $Date: 1998/07/14 09:32:31 $
-# $Revision: 1.18.1.13 $
+# $Date: 1999/05/17 09:18:32 $
+# $Revision: 1.18.1.14 $
 #
 package provide zircon 1.18
 #
@@ -21,12 +21,25 @@ proc userInvite {net chan} {
       [list ok "doInvite $net"] [list cancel {}]
 }
 #
+proc doMemo {net nk msg} {
+    switch {} $nk return
+    switch {} $msg return
+    $net addMemo $nk $msg
+    $net configure -lastuser $nk
+}
+#
 proc doMsg {net nk} {
     switch {} $nk return
     Message :: make $net $nk
     $net configure -lastuser $nk
 }
 #
+proc userMemo {net} {
+    mkEntryBox .@msg$net [trans message] {Enter user name:} \
+      [list [list user [$net lastuser]] [list message {}]] \
+      [list ok "doMemo $net"] [list cancel {}]
+}
+#
 proc userMessage {net} {
     mkEntryBox .@msg$net [trans message] {Enter user name:} \
       [list [list user [$net lastuser]]] \
@@ -106,6 +119,7 @@ proc userCmd {net cmd args} {
     Mode	{userMode $net}
     Finger	{userFinger $net}
     Invite	{userInvite $net {}}
+    Memo	{userMemo $net}
     Message	{userMessage $net}
     Notice	{userNotice $net}
     Kill	{userKill $net}
