@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/09/04 14:48:42 $
-# $Revision: 1.18.1.62 $
+# $Date: 1998/11/06 10:07:51 $
+# $Revision: 1.18.1.63 $
 #
 package provide Dcc 1.18
 #
@@ -26,7 +26,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
     switch -- $args {} return
     if {[catch {set host [dectonet $addr]}]} return
     switch $wh Chat {
-	if {[catch {connect $host $port} sok]} {
+	if {[catch {$net connect $host $port} sok]} {
 	    $net display {} "*** Cannot connect to host $host ($sok)"
 	    return 0
 	}
@@ -87,7 +87,7 @@ proc doGetDCC {net wh usr addr port leng posn args} {
 	    }
 	}
 	set file [file join [file dirname $file] [file tail $file]]
-	set sk [socket -async $host $port]
+	set sk [[$net sockcmd] -async $host $port]
 	fconfigure $sk -blocking 1
 	fileevent $sk writable "startGet $sk $net [list $file] $usr $leng $posn"
     }
