@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/send.tcl,v $
-# $Date: 1998/07/21 12:59:36 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/09/04 14:48:43 $
+# $Revision: 1.18.1.31 $
 #
 package provide Dcc 1.18
 #
@@ -119,17 +119,21 @@ proc handleSend {net fln usr addr port leng posn auto} {
     }
     if {![info exists GetDir($net)]} {
 	switch {} [set GetDir($net) [dccAutoDir $net $fln]] {
-	    set GetDir($net) [pwd]
+	    if {[catch {set GetDir($net) [pwd]} msg]} {
+		tellError $net "pwd error" "Cannot get working directory name : $msg"
+	    }
 	}
     }
     set dir $GetDir($net)
     set msg "DCC Send request ($fln) from [$usr name]"
-    switch {} [set fl [tk_getSaveFile -initialdir $dir -initialfile $fln \
+    if {[catch {switch {} [set fl [tk_getSaveFile -initialdir $dir -initialfile $fln \
       -filetypes $zFileTypes]] {
 # user cancelled the op. Should we do something?
     } default {
 	set GetDir($net) [file dirname $fl]
 	doGetDCC $net Get $usr $addr $port $leng $posn $fl
+    }} err]} {
+        $net errmsg "File error: $err"
     }
 }
 #
@@ -146,7 +150,9 @@ proc handleSend {net fln usr addr port leng posn auto} {
     global GetDir
     if {![info exists GetDir($net)]} {
 	switch {} [set GetDir($net) [dccAutoDir $net $fln]] {
-		set GetDir($net) [pwd]
+		if {[catch {set GetDir($net) [pwd]} msg]} {
+		    tellError $net "pwd error" "Cannot get working directory name : $msg"
+		}
 	}
     }
     set msg "DCC Send request ($fln) from [$usr name]"
