@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/plugins/Sed/RCS/decrypt.tcl,v $
-# $Date: 1998/03/20 15:21:15 $
-# $Revision: 1.18.1.1 $
+# $Source: /home/nlfm/Zircon/plugins/Sed/RCS/decrypt.tcl,v $
+# $Date: 1999/05/17 09:18:33 $
+# $Revision: 1.19 $
 #
 package provide Sed 1.18.1
 #
@@ -24,6 +24,8 @@ proc debin {val} {
 }
 #
 proc decrypt {string key} {
+zshow "{$string} [string length $string]"
+zshow $key
     if {[set klen [string length $key]] == 0} {return {<ENCRYPTED TEXT>}}
     regsub -all {\$} $string "\\\$" string
     regsub -all {\[} $string "\\\[" string
@@ -38,10 +40,12 @@ proc decrypt {string key} {
     	binary scan $x c1 gx
     	lappend knx $gx
     }
+zshow "[subst $string] [string length [subst $string]]"
     foreach x [split [subst $string] {}] {
     	binary scan $x c1 gx
 	set vl [expr {$vern ^ $gx ^ [lindex $knx $cycle]}]
 	append str [binary format c1 $vl]
+zshow [binary format c1 $vl]
 	set vern [expr {$vern ^ $vl}]
 	set cycle [expr {($cycle + 1) % $klen}]
     }
@@ -56,6 +60,7 @@ proc encrypt {string key} {
     	binary scan $x c1 gx
     	lappend knx $gx
     }
+    set str {}
     foreach x [split $string {}] {
     	binary scan $x c1 gx
 	set vl [expr {$vern ^ $gx ^ [lindex $knx $cycle]}]
@@ -68,6 +73,6 @@ proc encrypt {string key} {
     regsub -all "\000" $str {\\0} str
     regsub -all "\n" $str {\\n} str
     regsub -all "\r" $str {\\r} str
-    return "\001SED$str\001"
+    return "\001SED $str\001"
 }
 }
